==> Acme-MetaSyntactic-Themes-1.001.tar.gz: Acme-MetaSyntactic-Themes-1.001/lib/Acme/MetaSyntactic/barbapapa.pm <==
package Acme::MetaSyntactic::barbapapa;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::barbapapa - The Barbapapa theme

=head1 DESCRIPTION

The Barbapapa family consists of 9 members, 7 children and 2 adults.
This cartoon series was created by French architect Annette Tison and
her American husband Talus Taylor in 1970. First as comic books, and
later as a television series.

The official Barbapapa web site is at L<http://www.barbapapa.fr/>.

=head1 CONTRIBUTOR

Abigail

Introduced in Acme-MetaSyntactic version 0.54, published on December 26, 2005.

Updated with the Italian, Spanish and Slovene version, and
received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 DEDICATION

Philippe dedicates this module to his niece Enora. Merry Christmas!

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
fr
# names fr
Barbapapa Barbamama  Barbabelle Barbotine    Barbalala  Barbidou Barbidur   Barbibul    Barbouille
# names en
Barbapapa Barbamama  Barbabelle Barbalib     Barbalala  Barbazoo Barbabravo Barbabright Barbabeau
# names nl
Barbapapa Barbamama  Barbabella Barbabientje Barbalala  Barbabee Barbaborre Barbabenno  Barbabob
# names de
Barbapapa Barbamama  Barbabella Barbaletta   Barbalala  Barbakus Barbawum   Barbarix    Barbabo
# names fi
Barbapapa Barbamama  Barbabelle Barbalib     Barbalala  Barbazoo Barbabravo Barbabright Barbabeau
# names pl
Barbapapa Barbamama  Barbabelle Barbotine    Barbalala  Barbidou Barbidur   Barbibul    Barbouille
# names sv
Barbapapa Barbamama  Barbafin   Barbabok     Barbalala  Barbazoo Barbastark Barbaflink  Barbaskon
# names it
Barbapapa Barbamamma Barbabella Barbottina   Barbalalla Barbazoo Barbaforte Barbabravo  Barbabarba
# names es
Barbapapa Barbamama  Barbabella Barbalib     Barbalala  Barbazoo Barbabravo Barbabrillo Barbabello
# names sl
Barbapapa Barbamama  Barbalepa  Barbabrala   Barbalala  Barbazoo Barbabravo Barbaplus   Barbazal

==> Acme-MetaSyntactic-Themes-1.055.tar.gz: Acme-MetaSyntactic-Themes-1.055/lib/Acme/MetaSyntactic/barbapapa.pm <==
package Acme::MetaSyntactic::barbapapa;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::barbapapa - The Barbapapa theme

=head1 DESCRIPTION

The Barbapapa family consists of 9 members, 7 children and 2 adults.
This cartoon series was created by French architect Annette Tison and
her American husband Talus Taylor in 1970. First as comic books, and
later as a television series.

The official Barbapapa web site is at L<http://www.barbapapa.fr/>.

=head1 CONTRIBUTORS

Abigail, Philippe Bruhat (BooK).

=head1 DEDICATION

Philippe dedicates this module to his niece Enora. Merry Christmas!

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Updated with the Italian, Spanish and Slovene version, and
received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-12-26

Introduced in Acme-MetaSyntactic version 0.54.

=item *

2005-10-25

Submitted by Abigail with seven languages (English, French, Dutch, German,
Finnish, Polish and Swedish).

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
fr
# names fr
Barbapapa Barbamama  Barbabelle Barbotine    Barbalala  Barbidou Barbidur   Barbibul    Barbouille
# names en
Barbapapa Barbamama  Barbabelle Barbalib     Barbalala  Barbazoo Barbabravo Barbabright Barbabeau
# names nl
Barbapapa Barbamama  Barbabella Barbabientje Barbalala  Barbabee Barbaborre Barbabenno  Barbabob
# names de
Barbapapa Barbamama  Barbabella Barbaletta   Barbalala  Barbakus Barbawum   Barbarix    Barbabo
# names fi
Barbapapa Barbamama  Barbabelle Barbalib     Barbalala  Barbazoo Barbabravo Barbabright Barbabeau
# names pl
Barbapapa Barbamama  Barbabelle Barbotine    Barbalala  Barbidou Barbidur   Barbibul    Barbouille
# names sv
Barbapapa Barbamama  Barbafin   Barbabok     Barbalala  Barbazoo Barbastark Barbaflink  Barbaskon
# names it
Barbapapa Barbamamma Barbabella Barbottina   Barbalalla Barbazoo Barbaforte Barbabravo  Barbabarba
# names es
Barbapapa Barbamama  Barbabella Barbalib     Barbalala  Barbazoo Barbabravo Barbabrillo Barbabello
# names sl
Barbapapa Barbamama  Barbalepa  Barbabrala   Barbalala  Barbazoo Barbabravo Barbaplus   Barbazal
